"""
ScraGet - A package used to make it easier to get data from the Scratch API.
Wiki: https://github.com/Quantum-Codes/ScraGet/wiki
"""


#idk why should I put these below
"""
from ScraGet.forum import get_post, get_topic
from ScraGet.project import get_project, project_comments
from ScraGet.cloud import get_cloud_data, cloud
from ScraGet.studios import get_studio
from ScraGet.user import get_user, get_user_extra
from ScraGet.frontpage import get_frontpage
from ScraGet.encoder import encoder
"""
#this is the only useful thing to put
from ScraGet import ScraGet